@@ -1,10 +1,10 @@
 from langchain_core.documents import Document
 from langchain_core.runnables import Runnable, RunnableConfig
 
-from mtmai.agents.states.ctx import get_mtmai_ctx
-from mtmai.agents.states.research_state import ResearchState
-from mtmai.core.logging import get_logger
+from mtmai.agents.ctx import mtmai_context
 
+from mtmai.core.logging import get_logger
+from mtmai.models.graph_config import ResearchState
 logger = get_logger()
 
 
@@ -17,8 +17,7 @@ class IndexReferencesNode:
 
     async def __call__(self, state: ResearchState, config: RunnableConfig):
         logger.info(f"进入 index_references node: {state}")
-        ctx = get_mtmai_ctx()
-        vs = ctx.vectorstore
+        vs = mtmai_context .vectorstore
 
         all_docs = []
         for interview_state in state["interview_results"]:
