@@ -1,9 +1,4 @@
-import logging
-
-
 def register_clean_commands(cli):
-    logger = logging.getLogger()
-
     @cli.command()
     def clean():
         """Run clean-up"""
