@@ -8,8 +8,6 @@ import click
 
 
 def register_db_commands(cli):
-
-
     @cli.group(invoke_without_command=True)
     @click.pass_context
     def db(ctx):
@@ -19,6 +17,6 @@ def register_db_commands(cli):
     @db.command()
     def default():
         """Database related commands"""
-        from mtmai.core.seed import init_database
+        from mtmai.cli.seed import init_database
 
         asyncio.run(init_database())
