@@ -15,7 +15,7 @@ from .__version__ import version
 # Get the directory the script is running from
 APP_ROOT = os.getenv("MTMAI_APP_ROOT", os.getcwd())
 
-HEADER_SITE_HOST = "X-Site-Host" # 通过http header 传递前端域名
+HEADER_SITE_HOST = "X-Site-Host"  # 通过http header 传递前端域名
 
 
 def parse_cors(v: Any) -> list[str] | str:
@@ -70,11 +70,11 @@ class Settings(BaseSettings):
 
     # db
     DATABASE_URL: str | None = None  # config("DATABASE_URL", cast=Secret)
-    DATABASE_URL_2: str | None = None
+    # DATABASE_URL_2: str | None = None
 
     API_V1_STR: str = "/api/v1"
     VERSION: str | None = version
-    OPENAPI_JSON_PATH: str = "mtmai/mtmai/openapi.json"
+    OPENAPI_JSON_PATH: str = "pyprojects/mtmai/mtmai/openapi.json"
 
     vercel_token: str | None = None
 
@@ -133,7 +133,7 @@ class Settings(BaseSettings):
     # storage
     @computed_field  # type: ignore[prop-decorator]
     @property
-    def storage_dir(self) -> str:  # str | None = "/app/storage"
+    def storage_dir(self) -> str:
         if mtutils.is_in_gitpod():
             return ".vol"
         return "/app/storage"
@@ -230,7 +230,7 @@ class Settings(BaseSettings):
     DOCKERHUB_PASSWORD: str | None = None
     DOCKERHUB_USER: str | None = None
 
-    DOCKER_IMAGE_TAG: str | None = "docker.io/gitgit188/tmpboai"
+    DOCKER_IMAGE_TAG: str | None = "docker.io/gitgit188/tmpboaiv3"
 
     # npm
 
@@ -262,6 +262,7 @@ class Settings(BaseSettings):
 
     # 其他
     graph_config_path: str = "configs/graph_config.yml"
+    mtforms_config_path: str = "configs/mtforms.yml"
     # chainlit
     CHAINLIT_AUTH_SECRET: str | None = None
 
@@ -272,6 +273,4 @@ class Settings(BaseSettings):
     WORKER_ENABLED: bool = True
 
 
-
-
 settings = Settings()  # type: ignore
