@@ -5,7 +5,6 @@ from pathlib import Path
 
 from mtmlib.github import git_commit_push
 from mtmlib.mtutils import bash
-from mtmlib.version_tag import patch_git_tag_version, read_tag
 
 from mtmai.core import coreutils
 from mtmai.core.config import settings
@@ -13,6 +12,9 @@ from mtmai.mtlibs import mtutils
 from mtmai.mtlibs.mtutils import command_exists, is_in_gitpod, npm_patch_version
 from mtmai.mtlibs.temboio import run_tmpbo_instance1
 
+# from mtmlib.version_tag import  read_tag
+
+
 logger = logging.getLogger()
 
 
@@ -33,15 +35,11 @@ async def init_project():
                 settings.DOCKERHUB_USER} --password-stdin) || true"
         )
 
-    # if settings.NPM_TOKEN:
-    #     npmrc = Path.home().joinpath(".npmrc")
-    #     npmrc.write_text(
-    #         f"//registry.npmjs.org/:_authToken={settings.NPM_TOKEN}\n")
-
-    # huggingface.hf_trans1_clone()
-
-    # if is_in_gitpod():
-    #     import threading
+    if settings.NPM_TOKEN:
+        if is_in_gitpod():
+            Path.home().joinpath(".npmrc").write_text(
+                f"//registry.npmjs.org/:_authToken={settings.NPM_TOKEN}\n"
+            )
 
     # from mtmlib import tunnel
     # threading.Thread(target=lambda: asyncio.run(
@@ -149,8 +147,8 @@ def run_testing():
 
 
 def release_py():
-    version_tag = read_tag()
-    logger.info("version tag: %s", version_tag)
+    # version_tag = read_tag()
+    # logger.info("version tag: %s", version_tag)
     # run_testing()
     for project in py_projects:
         dist_dir = Path(f"{project}/dist")
@@ -169,8 +167,8 @@ def release_py():
         mtutils.pyproject_patch_version(py_project_dir)
 
     release_npm()
-    next_version = patch_git_tag_version()
-    logger.info("✅ patch_git_tag_version ok!,next version tag: %s", next_version)
+    # next_version = patch_git_tag_version()
+    # logger.info("✅ patch_git_tag_version ok!,next version tag: %s", next_version)
 
 
 def release_npm():
@@ -190,7 +188,15 @@ def release_npm():
 
     for package in npm_packages:
         npm_patch_version(package)
-    bash("bun run changeset publish --no-git-tag")
+    NPM_TOKEN = os.getenv("NPM_TOKEN")
+    print("NPM_TOKEN", NPM_TOKEN)
+    if NPM_TOKEN:
+        bash(
+            f"export NPM_TOKEN={NPM_TOKEN} && bun run changeset publish --token {NPM_TOKEN} --no-git-tag"
+        )
+    else:
+        raise Exception("NPM_TOKEN 未设置")
+
     logger.info("✅ release_npm ok!")
 
 
